@@ -16,18 +16,23 @@ class CallChannel(
 	):
 
 	def __init__(self, connection, manager, props, contactHandle):
-		self._manager = manager
-		self._props = props
+		self.__manager = manager
+		self.__props = props
 
 		try:
 			# HACK Older python-telepathy way
 			telepathy.server.ChannelTypeStreamedMedia.__init__(self, connection, None)
+			self._requested = props[telepathy.interfaces.CHANNEL_INTERFACE + '.Requested']
+			self._implement_property_get(
+				telepathy.interfaces.CHANNEL_INTERFACE,
+				{"Requested": lambda: self._requested}
+			)
 		except TypeError:
 			# HACK Newer python-telepathy way
 			telepathy.server.ChannelTypeStreamedMedia.__init__(self, connection, manager, props)
 		telepathy.server.ChannelInterfaceCallState.__init__(self)
 		telepathy.server.ChannelInterfaceGroup.__init__(self)
-		self._contactHandle = contactHandle
+		self.__contactHandle = contactHandle
 		self._implement_property_get(
 			telepathy.interfaces.CHANNEL_TYPE_STREAMED_MEDIA,
 			{
@@ -36,21 +41,43 @@ class CallChannel(
 			},
 		)
 
+		self.GroupFlagsChanged(0, 0)
+		self.MembersChanged(
+			'', [self._conn.GetSetHandle()], [], [], [contactHandle],
+			0, telepathy.CHANNEL_GROUP_CHANGE_REASON_NONE
+		)
+
 	def initial_audio(self):
 		return False
 
 	def initial_video(self):
 		return False
 
+	def get_props(self):
+		# HACK Older python-telepathy doesn't provide this
+		_immutable_properties = {
+			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
+		}
+		props = dict()
+		for prop, iface in _immutable_properties.items():
+			props[iface + '.' + prop] = \
+				self._prop_getters[iface][prop]()
+		return props
+
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def Close(self):
 		self.close()
 
 	def close(self):
 		telepathy.server.ChannelTypeStreamedMedia.Close(self)
-		if self._manager.channel_exists(self._props):
+		if self.__manager.channel_exists(self.__props):
 			# HACK Older python-telepathy requires doing this manually
-			self._manager.remove_channel(self)
+			self.__manager.remove_channel(self)
 		self.remove_from_connection()
 
 	@gtk_toolbox.log_exception(_moduleLogger)
@@ -85,12 +112,12 @@ class CallChannel(
 		@returns [(Stream ID, contact, stream type, stream state, stream direction, pending send flags)]
 		"""
 		contact = self._conn.handle(telepathy.constants.HANDLE_TYPE_CONTACT, contactId)
-		assert self._contactHandle == contact, "%r != %r" % (self._contactHandle, contact)
+		assert self.__contactHandle == contact, "%r != %r" % (self.__contactHandle, contact)
 		contactId, contactNumber = handle.ContactHandle.from_handle_name(contact.name)
 
-		self.CallStateChanged(self._contactHandle, telepathy.constants.CHANNEL_CALL_STATE_RINGING)
+		self.CallStateChanged(self.__contactHandle, telepathy.constants.CHANNEL_CALL_STATE_RINGING)
 		self._conn.session.backend.call(contactNumber)
-		self.CallStateChanged(self._contactHandle, telepathy.constants.CHANNEL_CALL_STATE_FORWARDED)
+		self.CallStateChanged(self.__contactHandle, telepathy.constants.CHANNEL_CALL_STATE_FORWARDED)
 
 		streamId = 0
 		streamState = telepathy.constants.MEDIA_STREAM_STATE_DISCONNECTED
@@ -106,4 +133,4 @@ class CallChannel(
 		Get the current call states for all contacts involved in this call. 
 		@returns {Contact: telepathy.constants.CHANNEL_CALL_STATE_*}
 		"""
-		return {self._contactHandle: telepathy.constants.CHANNEL_CALL_STATE_FORWARDED}
+		return {self.__contactHandle: telepathy.constants.CHANNEL_CALL_STATE_FORWARDED}
