@@ -2,7 +2,6 @@ import logging
 
 import telepathy
 
-import util.go_utils as gobject_utils
 import util.coroutines as coroutines
 import gtk_toolbox
 import handle
@@ -11,41 +10,38 @@ import handle
 _moduleLogger = logging.getLogger("channel.contact_list")
 
 
-class AbstractListChannel(
+class AllContactsListChannel(
 		telepathy.server.ChannelTypeContactList,
 		telepathy.server.ChannelInterfaceGroup,
 	):
-	"Abstract Contact List channels"
-
-	def __init__(self, connection, manager, props, h):
-		self._manager = manager
-		self._props = props
-
-		try:
-			# HACK Older python-telepathy way
-			telepathy.server.ChannelTypeContactList.__init__(self, connection, h)
-		except TypeError:
-			# HACK Newer python-telepathy way
-			telepathy.server.ChannelTypeContactList.__init__(self, connection, manager, props)
-		telepathy.server.ChannelInterfaceGroup.__init__(self)
-
-		self._session = connection.session
-
-
-class AllContactsListChannel(AbstractListChannel):
 	"""
 	The group of contacts for whom you receive presence
 	"""
 
 	def __init__(self, connection, manager, props, h):
-		AbstractListChannel.__init__(self, connection, manager, props, h)
+		try:
+			# HACK Older python-telepathy way
+			telepathy.server.ChannelTypeContactList.__init__(self, connection, h)
+			self._requested = props[telepathy.interfaces.CHANNEL_INTERFACE + '.Requested']
+			self._implement_property_get(
+				telepathy.interfaces.CHANNEL_INTERFACE,
+				{"Requested": lambda: self._requested}
+			)
+		except TypeError:
+			# HACK Newer python-telepathy way
+			telepathy.server.ChannelTypeContactList.__init__(self, connection, manager, props)
+		telepathy.server.ChannelInterfaceGroup.__init__(self)
+
+		self.__manager = manager
+		self.__props = props
+		self.__session = connection.session
 
 		self._callback = coroutines.func_sink(
 			coroutines.expand_positional(
 				self._on_contacts_refreshed
 			)
 		)
-		self._session.addressbook.updateSignalHandler.register_sink(
+		self.__session.addressbook.updateSignalHandler.register_sink(
 			self._callback
 		)
 
@@ -55,23 +51,38 @@ class AllContactsListChannel(AbstractListChannel):
 		contacts = addressbook.get_contacts()
 		self._process_refresh(addressbook, contacts, [])
 
+	def get_props(self):
+		# HACK Older python-telepathy doesn't provide this
+		_immutable_properties = {
+			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
+		}
+		props = dict()
+		for prop, iface in _immutable_properties.items():
+			props[iface + '.' + prop] = \
+				self._prop_getters[iface][prop]()
+		return props
+
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def Close(self):
 		self.close()
 
 	def close(self):
-		self._session.addressbook.updateSignalHandler.unregister_sink(
+		self.__session.addressbook.updateSignalHandler.unregister_sink(
 			self._callback
 		)
 		self._callback = None
 
 		telepathy.server.ChannelTypeContactList.Close(self)
-		if self._manager.channel_exists(self._props):
+		if self.__manager.channel_exists(self.__props):
 			# HACK Older python-telepathy requires doing this manually
-			self._manager.remove_channel(self)
+			self.__manager.remove_channel(self)
 		self.remove_from_connection()
 
-	@gobject_utils.async
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def _on_contacts_refreshed(self, addressbook, added, removed, changed):
 		self._process_refresh(addressbook, added, removed)
