@@ -18,21 +18,42 @@ class DebugPromptChannel(telepathy.server.ChannelTypeText, cmd.Cmd):
 	"""
 
 	def __init__(self, connection, manager, props, contactHandle):
-		self._manager = manager
-		self._props = props
+		self.__manager = manager
+		self.__props = props
 
 		cmd.Cmd.__init__(self, "Debug Prompt")
 		self.use_rawinput = False
 		try:
 			# HACK Older python-telepathy way
 			telepathy.server.ChannelTypeText.__init__(self, connection, contactHandle)
+			self._requested = props[telepathy.interfaces.CHANNEL_INTERFACE + '.Requested']
+			self._implement_property_get(
+				telepathy.interfaces.CHANNEL_INTERFACE,
+				{"Requested": lambda: self._requested}
+			)
 		except TypeError:
 			# HACK Newer python-telepathy way
 			telepathy.server.ChannelTypeText.__init__(self, connection, manager, props)
-		self._nextRecievedId = 0
-		self._lastMessageTimestamp = datetime.datetime(1, 1, 1)
+		self.__nextRecievedId = 0
+		self.__lastMessageTimestamp = datetime.datetime(1, 1, 1)
 
-		self._otherHandle = contactHandle
+		self.__otherHandle = contactHandle
+
+	def get_props(self):
+		# HACK Older python-telepathy doesn't provide this
+		_immutable_properties = {
+			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
+		}
+		props = dict()
+		for prop, iface in _immutable_properties.items():
+			props[iface + '.' + prop] = \
+				self._prop_getters[iface][prop]()
+		return props
 
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def Send(self, messageType, text):
@@ -57,20 +78,20 @@ class DebugPromptChannel(telepathy.server.ChannelTypeText, cmd.Cmd):
 
 	def close(self):
 		telepathy.server.ChannelTypeText.Close(self)
-		if self._manager.channel_exists(self._props):
+		if self.__manager.channel_exists(self.__props):
 			# HACK Older python-telepathy requires doing this manually
-			self._manager.remove_channel(self)
+			self.__manager.remove_channel(self)
 		self.remove_from_connection()
 
 	def _report_new_message(self, message):
-		currentReceivedId = self._nextRecievedId
+		currentReceivedId = self.__nextRecievedId
 
 		timestamp = int(time.time())
 		type = telepathy.CHANNEL_TEXT_MESSAGE_TYPE_NORMAL
 
-		self.Received(currentReceivedId, timestamp, self._otherHandle, type, 0, message.strip())
+		self.Received(currentReceivedId, timestamp, self.__otherHandle, type, 0, message.strip())
 
-		self._nextRecievedId += 1
+		self.__nextRecievedId += 1
 
 	def do_reset_state_machine(self, args):
 		if args:
@@ -78,7 +99,8 @@ class DebugPromptChannel(telepathy.server.ChannelTypeText, cmd.Cmd):
 			return
 
 		try:
-			self._conn.session.stateMachine.reset_timers()
+			for machine in self._conn.session.stateMachine._machines:
+				machine.reset_timers()
 		except Exception, e:
 			self._report_new_message(str(e))
 
@@ -88,7 +110,7 @@ class DebugPromptChannel(telepathy.server.ChannelTypeText, cmd.Cmd):
 			return
 
 		try:
-			state = self._conn.session.stateMachine.get_state()
+			state = self._conn.session.stateMachine.state
 			self._report_new_message(str(state))
 		except Exception, e:
 			self._report_new_message(str(e))
