@@ -4,7 +4,6 @@ import logging
 
 import telepathy
 
-import util.go_utils as gobject_utils
 import util.coroutines as coroutines
 import gtk_toolbox
 
@@ -18,45 +17,75 @@ class TextChannel(telepathy.server.ChannelTypeText):
 	"""
 
 	def __init__(self, connection, manager, props, contactHandle):
-		self._manager = manager
-		self._props = props
+		self.__manager = manager
+		self.__props = props
 
 		try:
 			# HACK Older python-telepathy way
 			telepathy.server.ChannelTypeText.__init__(self, connection, contactHandle)
+			self._requested = props[telepathy.interfaces.CHANNEL_INTERFACE + '.Requested']
+			self._implement_property_get(
+				telepathy.interfaces.CHANNEL_INTERFACE,
+				{"Requested": lambda: self._requested}
+			)
 		except TypeError:
 			# HACK Newer python-telepathy way
 			telepathy.server.ChannelTypeText.__init__(self, connection, manager, props)
-		self._nextRecievedId = 0
-		self._lastMessageTimestamp = datetime.datetime(1, 1, 1)
+		self.__nextRecievedId = 0
+		self.__lastMessageTimestamp = datetime.datetime(1, 1, 1)
 
-		self._otherHandle = contactHandle
+		self.__otherHandle = contactHandle
 
-		self._callback = coroutines.func_sink(
+		self.__callback = coroutines.func_sink(
 			coroutines.expand_positional(
 				self._on_conversations_updated
 			)
 		)
-		self._conn.session.conversations.updateSignalHandler.register_sink(
-			self._callback
+		self._conn.session.voicemails.updateSignalHandler.register_sink(
+			self.__callback
+		)
+		self._conn.session.texts.updateSignalHandler.register_sink(
+			self.__callback
 		)
 
 		# The only reason there should be anything in the conversation is if
 		# its new, so report it all
 		try:
-			mergedConversations = self._conn.session.conversations.get_conversation(self._contactKey)
+			mergedConversations = self._conn.session.voicemails.get_conversation(self._contactKey)
 		except KeyError:
-			_moduleLogger.info("Nothing in the conversation yet for %r" % (self._contactKey, ))
+			_moduleLogger.debug("Nothing in the conversation yet for %r" % (self._contactKey, ))
 		else:
 			self._report_conversation(mergedConversations)
+		try:
+			mergedConversations = self._conn.session.texts.get_conversation(self._contactKey)
+		except KeyError:
+			_moduleLogger.debug("Nothing in the conversation yet for %r" % (self._contactKey, ))
+		else:
+			self._report_conversation(mergedConversations)
+
+	def get_props(self):
+		# HACK Older python-telepathy doesn't provide this
+		_immutable_properties = {
+			'ChannelType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandle': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Interfaces': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetHandleType': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'TargetID': telepathy.server.interfaces.CHANNEL_INTERFACE,
+			'Requested': telepathy.server.interfaces.CHANNEL_INTERFACE
+		}
+		props = dict()
+		for prop, iface in _immutable_properties.items():
+			props[iface + '.' + prop] = \
+				self._prop_getters[iface][prop]()
+		return props
 
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def Send(self, messageType, text):
 		if messageType != telepathy.CHANNEL_TEXT_MESSAGE_TYPE_NORMAL:
 			raise telepathy.errors.NotImplemented("Unhandled message type: %r" % messageType)
 
-		self._conn.session.backend.send_sms(self._otherHandle.phoneNumber, text)
-		self._conn.session.stateMachine.reset_timers()
+		self._conn.session.backend.send_sms(self.__otherHandle.phoneNumber, text)
+		self._conn.session.textsStateMachine.reset_timers()
 
 		self.Sent(int(time.time()), messageType, text)
 
@@ -65,29 +94,31 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		self.close()
 
 	def close(self):
-		self._conn.session.conversations.updateSignalHandler.unregister_sink(
-			self._callback
+		self._conn.session.voicemails.updateSignalHandler.unregister_sink(
+			self.__callback
 		)
-		self._callback = None
+		self._conn.session.texts.updateSignalHandler.unregister_sink(
+			self.__callback
+		)
+		self.__callback = None
 
 		telepathy.server.ChannelTypeText.Close(self)
-		if self._manager.channel_exists(self._props):
+		if self.__manager.channel_exists(self.__props):
 			# HACK Older python-telepathy requires doing this manually
-			self._manager.remove_channel(self)
+			self.__manager.remove_channel(self)
 		self.remove_from_connection()
 
 	@property
 	def _contactKey(self):
-		contactKey = self._otherHandle.contactID, self._otherHandle.phoneNumber
+		contactKey = self.__otherHandle.contactID, self.__otherHandle.phoneNumber
 		return contactKey
 
-	@gobject_utils.async
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def _on_conversations_updated(self, conv, conversationIds):
 		if self._contactKey not in conversationIds:
 			return
-		_moduleLogger.info("Incoming messages from %r for existing conversation" % (self._contactKey, ))
-		mergedConversations = self._conn.session.conversations.get_conversation(self._contactKey)
+		_moduleLogger.debug("Incoming messages from %r for existing conversation" % (self._contactKey, ))
+		mergedConversations = conv.get_conversation(self._contactKey)
 		self._report_conversation(mergedConversations)
 
 	def _report_conversation(self, mergedConversations):
@@ -96,11 +127,11 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		newConversations = self._filter_out_read(newConversations)
 		newConversations = list(newConversations)
 		if not newConversations:
-			_moduleLogger.info(
+			_moduleLogger.debug(
 				"New messages for %r have already been read externally" % (self._contactKey, )
 			)
 			return
-		self._lastMessageTimestamp = newConversations[-1].time
+		self.__lastMessageTimestamp = newConversations[-1].time
 
 		messages = [
 			newMessage
@@ -109,7 +140,7 @@ class TextChannel(telepathy.server.ChannelTypeText):
 			if newMessage.whoFrom != "Me:"
 		]
 		if not newConversations:
-			_moduleLogger.info(
+			_moduleLogger.debug(
 				"All incoming messages were really outbound messages for %r" % (self._contactKey, )
 			)
 			return
@@ -122,7 +153,7 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		return (
 			conversation
 			for conversation in conversations
-			if self._lastMessageTimestamp < conversation.time
+			if self.__lastMessageTimestamp < conversation.time
 		)
 
 	def _filter_out_read(self, conversations):
@@ -136,12 +167,11 @@ class TextChannel(telepathy.server.ChannelTypeText):
 		return " ".join(part.text.strip() for part in message.body)
 
 	def _report_new_message(self, message):
-		currentReceivedId = self._nextRecievedId
-
+		currentReceivedId = self.__nextRecievedId
 		timestamp = int(time.time())
 		type = telepathy.CHANNEL_TEXT_MESSAGE_TYPE_NORMAL
 
-		_moduleLogger.info("Received message from User %r" % self._otherHandle)
-		self.Received(currentReceivedId, timestamp, self._otherHandle, type, 0, message)
+		_moduleLogger.info("Received message from User %r" % self.__otherHandle)
+		self.Received(currentReceivedId, timestamp, self.__otherHandle, type, 0, message)
 
-		self._nextRecievedId += 1
+		self.__nextRecievedId += 1
